import { IEditorContentManagerOptions } from "./IEditorContentManagerOptions";
/**
 * The EditorContentManager facilitates listening to local content changes and
 * the playback of remote content changes into the editor.
 */
export declare class EditorContentManager {
    private _operationQueue;
    /**
     * Constructs a new EditorContentManager using the supplied options.
     *
     * @param options
     *   The options that configure the EditorContentManager.
     */
    constructor(options: IEditorContentManagerOptions);
    /**
     * Inserts text into the editor.
     *
     * @param index
     *   The index to insert text at.
     * @param text
     *   The text to insert.
     */
    insert(index: number, text: string): void;
    /**
     * Replaces text in the editor.
     *
     * @param index
     *   The start index of the range to replace.
     * @param length
     *   The length of the  range to replace.
     * @param text
     *   The text to insert.
     */
    replace(index: number, length: number, text: string): void;
    /**
     * Deletes text in the editor.
     *
     * @param index
     *   The start index of the range to remove.
     * @param length
     *   The length of the  range to remove.
     */
    delete(index: number, length: number): void;
    /**
     * Disposes of the content manager, freeing any resources.
     */
    dispose(): void;
}
